var doStem = true;
//List of indexed files.
fl = new Array();
fl["0"]= "ch02.html";
fl["1"]= "ch03s02.html";
fl["2"]= "ch02s03.html";
fl["3"]= "ch03s01.html";
fl["4"]= "ch05.html";
fl["5"]= "index.html";
fl["6"]= "ch02s01.html";
fl["7"]= "ch02s05.html";
fl["8"]= "ch02s02s01.html";
fl["9"]= "ch03s02s01.html";
fl["10"]= "ch01.html";
fl["11"]= "ch04.html";
fl["12"]= "ch05s02.html";
fl["13"]= "ch02s04.html";
fl["14"]= "ch05s01.html";
fl["15"]= "ch02s02.html";
fl["16"]= "ch03.html";
fil = new Array();
fil["0"]= "ch02.html@@@Using the package@@@java available in your PATH...";
fil["1"]= "ch03s02.html@@@Search@@@Overview design of Search mechanism...";
fil["2"]= "ch02s03.html@@@Search indexing@@@To build the indexer, you must have installed the JDK version 1.5 or higher and set the ANT_HOME environment variable...";
fil["3"]= "ch03s01.html@@@Design@@@An overview of webhelp page structure...";
fil["4"]= "ch05.html@@@Test section@@@null";
fil["5"]= "index.html@@@README: Web-based Help from DocBook XML@@@null";
fil["6"]= "ch02s01.html@@@Generating webhelp output using the Ant build.xml file@@@Installation instructions...";
fil["7"]= "ch02s05.html@@@Adding images@@@null";
fil["8"]= "ch02s02s01.html@@@Recommended Apache configurations@@@null";
fil["9"]= "ch03s02s01.html@@@New Stemmers@@@Adding new Stemmers is very simple...";
fil["10"]= "ch01.html@@@Introduction@@@Overview of the package...";
fil["11"]= "ch04.html@@@FAQ@@@Frequently Asked Questions...";
fil["12"]= "ch05s02.html@@@Some search words for testing (inflected)@@@null";
fil["13"]= "ch02s04.html@@@Adding support for other (non-CJKV) languages@@@null";
fil["14"]= "ch05s01.html@@@Some search words for testing@@@null";
fil["15"]= "ch02s02.html@@@Using and customizing the output@@@null";
fil["16"]= "ch03.html@@@Developer Docs@@@This chapter provides an overview of how webhelp is implemented...";
